aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-btrfcomm.h
diff options
context:
space:
mode:
Diffstat (limited to 'epan/dissectors/packet-btrfcomm.h')
-rw-r--r--epan/dissectors/packet-btrfcomm.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/epan/dissectors/packet-btrfcomm.h b/epan/dissectors/packet-btrfcomm.h
index 78c2b83dae..c613c3be31 100644
--- a/epan/dissectors/packet-btrfcomm.h
+++ b/epan/dissectors/packet-btrfcomm.h
@@ -27,13 +27,14 @@
extern int proto_btrfcomm;
typedef struct _btrfcomm_data_t {
- guint32 interface_id;
- guint32 adapter_id;
- guint16 chandle; /* only low 12 bits used */
- guint16 cid;
- guint8 dlci;
- guint32 remote_bd_addr_oui;
- guint32 remote_bd_addr_id;
+ guint32 interface_id;
+ guint32 adapter_id;
+ guint16 chandle; /* only low 12 bits used */
+ guint16 cid;
+ gboolean is_local_psm; /* otherwise it is PSM in remote device */
+ guint8 dlci;
+ guint32 remote_bd_addr_oui;
+ guint32 remote_bd_addr_id;
} btrfcomm_data_t;
#endif